"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var mockFactory_1 = require("../test/mockFactory");
var utils_1 = require("./utils");
describe("utils", function () {
    var sls;
    beforeEach(function () {
        var slsConfig = {
            service: "My test service",
            provider: "azure",
            functions: mockFactory_1.MockFactory.createTestSlsFunctionConfig(),
        };
        sls = mockFactory_1.MockFactory.createTestServerless();
        Object.assign(sls.service, slsConfig);
    });
    it("resolves handler when handler code is outside function folders", function () {
        sls.service["functions"].hello.handler = "src/handlers/hello.handler";
        mockFactory_1.MockFactory.updateService(sls);
        var functions = sls.service.getAllFunctions();
        var metadata = utils_1.Utils.getFunctionMetaData(functions[0], sls);
        var expectedMetadata = {
            entryPoint: "handler",
            handlerPath: path_1.default.normalize("../src/handlers/hello.js"),
            params: expect.anything(),
        };
        expect(metadata).toEqual(expectedMetadata);
    });
    it("resolves handler when code is in function folder", function () {
        sls.service["functions"].hello.handler = "hello/index.handler";
        mockFactory_1.MockFactory.updateService(sls);
        var functions = sls.service.getAllFunctions();
        var metadata = utils_1.Utils.getFunctionMetaData(functions[0], sls);
        var expectedMetadata = {
            entryPoint: "handler",
            handlerPath: path_1.default.normalize("index.js"),
            params: expect.anything(),
        };
        expect(metadata).toEqual(expectedMetadata);
    });
    it("resolves handler when code is at the project root", function () {
        sls.service["functions"].hello.handler = "hello.handler";
        mockFactory_1.MockFactory.updateService(sls);
        var functions = sls.service.getAllFunctions();
        var metadata = utils_1.Utils.getFunctionMetaData(functions[0], sls);
        var expectedMetadata = {
            entryPoint: "handler",
            handlerPath: path_1.default.normalize("../hello.js"),
            params: expect.anything(),
        };
        expect(metadata).toEqual(expectedMetadata);
    });
    it("should create string from substrings", function () {
        expect(utils_1.Utils.appendSubstrings(2, "abcde", "fghij", "klmno", "pqrst", "uvwxyz", "ab")).toEqual("abfgklpquvab");
    });
    it("Creates a short name for an azure region", function () {
        var expected = "ausse";
        var actual = utils_1.Utils.createShortAzureRegionName("australiasoutheast");
        expect(actual).toEqual(expected);
    });
    it("Creates a short stage name from a well known name", function () {
        var expected = "prod";
        var actual = utils_1.Utils.createShortStageName("production");
        expect(actual).toEqual(expected);
    });
    it("Creates a short stage name from a unknown name", function () {
        var value = "user acceptance";
        var actual = utils_1.Utils.createShortStageName(value);
        expect(actual).toEqual(value.substr(0, 3));
    });
    it("Creates a short stage name from multiple values", function () {
        var actual = utils_1.Utils.createShortStageName("production dogfood");
        expect(actual).toEqual("proddf");
    });
    it("Creates unique short names for all azure regions", function () {
        var regions = [
            "eastasia",
            "southeastasia",
            "centralus",
            "eastus",
            "eastus2",
            "westus",
            "northcentralus",
            "southcentralus",
            "northeurope",
            "westeurope",
            "japanwest",
            "japaneast",
            "brazilsouth",
            "australiaeast",
            "australiasoutheast",
            "southindia",
            "centralindia",
            "westindia",
            "canadacentral",
            "canadaeast",
            "uksouth",
            "ukwest",
            "westcentralus",
            "westus2",
            "koreacentral",
            "koreasouth",
            "francecentral",
            "francesouth",
            "australiacentral",
            "australiacentral2",
            "uaecentral",
            "uaenorth",
            "southafricanorth",
            "southafricawest"
        ];
        var results = {};
        regions.forEach(function (region) {
            var result = utils_1.Utils.createShortAzureRegionName(region);
            results[result] = region;
        });
        expect(Object.keys(results)).toHaveLength(regions.length);
    });
    it("gets a normalized region name from full region name", function () {
        var result = utils_1.Utils.getNormalizedRegionName("West US 2");
        expect(result).toEqual("westus2");
    });
    it("Performs noop if region name is already normalized", function () {
        var expected = "westus2";
        var actual = utils_1.Utils.getNormalizedRegionName(expected);
        expect(actual).toEqual(expected);
    });
    it("should get a timestamp from a name", function () {
        expect(utils_1.Utils.getTimestampFromName("myDeployment-t12345")).toEqual("12345");
        expect(utils_1.Utils.getTimestampFromName("myDeployment-t678987645")).toEqual("678987645");
        expect(utils_1.Utils.getTimestampFromName("-t12345")).toEqual("12345");
        expect(utils_1.Utils.getTimestampFromName("myDeployment-t")).toEqual(null);
        expect(utils_1.Utils.getTimestampFromName("")).toEqual(null);
    });
    it("should get incoming binding", function () {
        expect(utils_1.Utils.getIncomingBindingConfig(mockFactory_1.MockFactory.createTestAzureFunctionConfig())).toEqual({
            http: true,
            "x-azure-settings": mockFactory_1.MockFactory.createTestHttpBinding("in"),
        });
    });
    it("should get outgoing binding", function () {
        expect(utils_1.Utils.getOutgoingBinding(mockFactory_1.MockFactory.createTestAzureFunctionConfig())).toEqual({
            http: true,
            "x-azure-settings": mockFactory_1.MockFactory.createTestHttpBinding("out"),
        });
    });
});
